@@ -1,9 +1,7 @@
 import aiofiles
 import errno
-import logging
-import os
 
-log = logging.getLogger(__name__)
+import os
 
 
 async def load_iqn(hub):
@@ -22,7 +20,7 @@ async def load_iqn(hub):
                         iscsi_iqn.append(line.split("=", 1)[1])
         except IOError as ex:
             if ex.errno != errno.ENOENT:
-                log.debug(f"Error while accessing '{initiator}': {ex}")
+                hub.log.debug(f"Error while accessing '{initiator}': {ex}")
 
         if iscsi_iqn:
             hub.corn.CORN.iscsi_iqn = iscsi_iqn
