@@ -1,10 +1,8 @@
 import dns.resolver
-import logging
+
 import ipaddress
 from typing import Any, Dict, List
 
-log = logging.getLogger(__name__)
-
 
 async def _cidr_to_ipv4_netmask(cidr_bits: str or int) -> str:
     """
@@ -90,7 +88,7 @@ async def _get_sortlist(ip_addrs: List[str]) -> List[str]:
         try:
             ip_net = ipaddress.ip_network(ip_raw)
         except ValueError as exc:
-            log.error(exc)
+            hub.log.error(exc)
         else:
             if "/" not in ip_raw:
                 # No netmask has been provided, guess
