@@ -3,7 +3,7 @@ import os
 
 async def load_uname(hub):
     """
-    Verify that POP linux is running on linux
+    Verify that idem-linux is running on linux
     """
     (
         hub.corn.CORN.kernel,
@@ -15,10 +15,4 @@ async def load_uname(hub):
 
     assert (
         hub.corn.CORN.kernel == "Linux"
-    ), "POP-Linux is only intended for Linux systems"
-
-    # This will probably get deleted and overridden later
-    if not hub.corn.CORN.get("ps"):
-        hub.corn.CORN.ps = "ps -efHww"
-
-    hub.corn.CORN.uuid = "TODO"
\ No newline at end of file
+    ), "idem-Linux is only intended for Linux systems"
