@@ -1,12 +1,12 @@
 # -*- coding: utf-8 -*-
 import asyncio
 import functools
-import logging
+import dict_tools
+
 import os
 import shlex
 from typing import Any, Dict, List
 
-log = logging.getLogger(__name__)
 
 __virtualname__ = "cmd"
 
@@ -15,7 +15,7 @@ async def _sanitize_env(env: Dict[str, Any]) -> Dict[str, str] or None:
     if env is None:
         return
     for bad_env_key in (k for k, v in env.items() if v is None):
-        log.error(
+        hub.log.error(
             "Environment variable '%s' passed without a value. "
             "Setting value to an empty string",
             bad_env_key,
@@ -52,7 +52,7 @@ async def _sanitize_cwd(cwd: str or None) -> str:
 async def _sanitize_cmd(cmd: str or List[str]) -> str or List[str]:
     if not isinstance(cmd, list):
         cmd = cmd.split()
-    # Return stripped command string copies to improve logging.
+
     # Use shlex.quote to properly escape whitespace and special characters in strings passed to shells
     if isinstance(cmd, list):
         cmd = [shlex.quote(str(x).strip()) for x in cmd]
@@ -156,7 +156,7 @@ async def run(
 
     # This is where the magic happens
     out, err = await asyncio.wait_for(proc.communicate(input=stdin), timeout=timeout)
-
+    # TODO do a wrapper around a dict that makes it namespace addressable
     return hub.pop.data.imap(
         {
             "pid": proc.pid,
